/*

	Nonzero1.0 by nodethirtythree design
	http://www.nodethirtythree.com
	missing in a maze

*/

/* This controls the width of the fluid width layouts */


div.fluid
{
width: 90% !important;
}

/* This controls the width of the fixed width layouts */

div.fixed
{
width: 950px !important;
}

/* Basic Stuff */

*
{
margin: 0em;
padding: 0em;
}

body
{
background-color: #fff;
color: #585858;
font-size: 9pt;
font-family: "trebuchet ms", helvetica, sans-serif;
}

h1,h2,h3,h4,h5,h6
{
font-weight: normal;
/* letter-spacing: -1px; */
/* text-transform: lowercase; */
}

h1,
#secondaryContent_2columns h4
{
/*   letter-spacing: -1px; */
}

h3,h4,h5,h6
{
color: #66000F;
}

h1 span
{
font-weight: bold;
}

h1 a
{
text-decoration: none;
color: #fff;
}

h1 a:hover
{
text-decoration: underline;
}



h3 span
{
font-weight: bold;
}

h4 span
{
font-weight: bold;
}

br.clear
{
clear: both;
}

img
{
padding: 3px;
border: solid 1px #e1e1e1;
}

img.floatTL
{
float: left;
margin-right: 1.5em;
margin-bottom: 1.5em;
margin-top: 0.5em;
}

a
{
text-decoration: underline;
color: #66000F;
}

a:hover
{
text-decoration: none;
}


ul.links
{
list-style: none;
}

ul.links li
{
line-height: 2em;
}

ul.links li.first
{
}

p
{
line-height: 1.8em;
}

/* ------------------------------- dimmed down report groups ---------------------------- */
tr.justgroupmember a
{
  text-decoration: none;
  color: #BBB;
}

tr.justgroupmember a:hover
{
  text-decoration: underline;
  color: #BBB;
}

tr.highlight
{
  background-color: #fafad2
}

tr.highlightgrey
{
  background-color: #eeeeee
}



/* Header */

#header
{
top: 0;
left: 0;
right: 0;
position: fixed;
height:55px;
background: #440000 url('/tapper/static/images_red/n1.small.gif') repeat-x;
}

#header_inner
{
position: relative;
width: 950px;
height:55px;
margin: 0 auto;
}

/* Logo */

#logo
{
position: absolute;
bottom: 0.6em;
}

#logo h1
{
display: inline;
color: #fff;
font-size: 2.6em;
}

#logo h2
{
position: absolute;
display: inline;
color: #fff;
font-size: 1.5em;
top: 10px;
left: 215px;
width: 600px;
}

/* Menu */

#menu
{
position: absolute;
right: 0em;
bottom: 0em;
}

#menu ul
{
list-style: none;
}

#menu li
{
float: left;
}

#menu li a
{
    margin-left: 0.5em;
    display: block;
    padding: 1.1em 1.4em 1.0em 1.4em;
    background: #fff url('/tapper/static/images_red/n4.gif') repeat-x;
    border: solid 1px #fff;
    color: #616161;
    font-weight: bold;
    font-size: 1.0em;
    /* text-transform: lowercase; */
    text-decoration: none;
}

#menu li a.active
{
    background: #CA2F2F url('/tapper/static/images_red/n3.gif') repeat-x;
    color: #fff;
    border: solid 1px #A94B4B;
}

/* Main */

#main
{
    position: absolute;
    overflow: auto;
    top:55px;
    bottom: 0;
    left: 0;
    right: 0;
    background: #fff url('/tapper/static/images_red/n2.gif') 0px 1px repeat-x;
}

#main_inner p
{
text-align: justify;
margin-bottom: 2.0em;
}

#main_inner ul
{
margin-bottom: 2.0em;
list-style: none;
}

#main_inner
{
position: relative;
width: 950px;
margin: 0 auto;
padding-top: 20px;
}

#main_inner h3,h4
{
border-bottom: dotted 1px #E1E1E1;
position: relative;
}

#main_inner h3
{
font-size: 2.1em;
padding-bottom: 0.1em;
margin-bottom: 0.8em;
}


#main_inner h4
{
font-size: 1.2em;
padding-bottom: 0.175em;
margin-bottom: 1.4em;
margin-top: 0.95em;
}

#main_inner .post
{
position: relative;
}

#main_inner .post h3
{
position: relative;
font-size: 1.7em;
padding-bottom: 1.2em;
/* padding-top: 1.2em; */
}

#main_inner .post h3.testplan
{
position: relative;
font-size: 1.7em;
padding-bottom: 0em;
}


#main_inner .post ul.post_info
{
list-style: none;
position: absolute;
top: 3em;
font-size: 0.8em;
}

#main_inner .post ul.post_info li
{
background-position: 0em 0.2em;
background-repeat: no-repeat;
display: inline;
padding-left: 18px;
}

#main_inner .post ul.post_info li.date
{
background-image: url('/tapper/static/images_red/n5.gif');
}

#main_inner .post ul.post_info li.comments
{
background-image: url('/tapper/static/images_red/n6.gif');
margin-left: 1.1em;
}

/* ss5 */
#main_inner .post ul.post_info li.meta
{
background-image: url('/tapper/static/images_red/n5.gif');
margin-left: 1.1em;
}

/* Footer */

#footer
{
width: 950px;
margin: 0 auto;
text-align: center;
clear: both;
border-top: dotted 1px #E1E1E1;
margin-top: 1.0em;
margin-bottom: 1.0em;
padding-top: 1.0em;
/* text-transform: lowercase; */
}

/* Search */

input.button
{
background: #CA2F2F url('/tapper/static/images_red/n3.gif') repeat-x;
color: #fff;
border: solid 1px #A94B4B;
font-weight: bold;
text-transform: lowercase;
font-size: 0.8em;
height: 2.0em;
}

input.text
{
border: solid 1px #F1F1F1;
font-size: 1.0em;
padding: 0.25em 0.25em 0.25em 0.25em;
}

#search
{
position: relative;
width: 100%;
margin-bottom: 2.0em;
}

#search input.text
{
position: absolute;
top: 0em;
left: 0em;
width: 9.5em;
}

#search input.button
{
position: absolute;
top: 0em;
right: 0em;
min-width: 2.0em;
max-width: 2.5em;
}

/* LAYOUT - 3 COLUMNS */

	/* Primary content */

	#primaryContent_3columns
	{
	position: relative;
	margin-right: 34em;
	}

	#columnA_3columns
	{
	position: relative;
	float: left;
	width: 100%;
	margin-right: -34em;
	padding-right: 2em;
	}

	/* Secondary Content */

	#secondaryContent_3columns
	{
	float: right;
	}

	#columnB_3columns
	{
	width: 13.0em;
	float: left;
	padding: 0em 2em 0.5em 2em;
	border-left: dotted 1px #E1E1E1;
	}

	#columnC_3columns
	{
	width: 13.0em;
	float: left;
	padding: 0em 0em 0.5em 2em;
	border-left: dotted 1px #E1E1E1;
	}

/* LAYOUT - 2 COLUMNS */

	/* Primary content */

	#primaryContent_2columns
	{
	position: relative;
	margin-right: 17em;
	}

	#columnA_2columns
	{
	position: relative;
	float: left;
	width: 100%;
	margin-right: -17em;
	padding-right: 2em;
	}

	/* Secondary Content */

	#secondaryContent_2columns
	{
	float: right;
	}

	#columnC_2columns
	{
	width: 13.0em;
	float: left;
	padding: 0em 0em 0.5em 2em;
	border-left: dotted 1px #E1E1E1;
	}

/* LAYOUT - COLUMNLESS */

	/* Primary content */

	#primaryContent_columnless
	{
	position: relative;
	}

	#columnA_columnless
	{
	position: relative;
	width: 100%;
	}

/* ss5 - tapper - osrc */

/* ----- report list ----- */

table.reportlist
{
  text-align: left;
  }

table.reportlist tr
{
  padding: 0em 0em 1em 0em;
  }

table.reportlist th,
table.reportlist td
{
  padding: 0em 1em 0em 0em;
  }

table.reportlist th.reportid
{
  text-align: right;
  }

table.reportlist img
{
  padding: 0px;
  border: none;
  }

.fail
{
  color: #b55;
  }

.pass
{
  color: #5b5;
  }

.unknown
{
  color: #bb5;
  }

.navilink img
{
 padding: 0px 0px 0px 5px;
 border: none;
 vertical-align: middle;
}

.navilink a
{
 vertical-align: middle;
}

/* ----- suite list ----- */

table.suitelist
{
  text-align: left;
  }

table.suitelist tr
{
  padding: 0em 0em 1em 0em;
  }

table.suitelist th,
table.suitelist td
{
  padding: 0em 1em 0em 0em;
  }

table.suitelist th.suiteid,
table.suitelist td.suiteid
{
  text-align: right;
  }

/* ----- report section meta ----- */

table.reportsectionmeta
{
  text-align: left;
  }

table.reportsectionmeta tr
{
  padding: 0em 0em 1em 0em;
  }

table.reportsectionmeta td
{
  padding: 0em 1em 0em 0em;
  font-weight: bold;
  }

table.reportsectionmeta th
{
  padding: 0em 1em 0em 2em;
  vertical-align: top
  }

table.reportsectionmeta th
{
  font-weight: normal;
  }

table.reportsectionmeta h5
{
  padding: 0.5em 0em 0em 0em;
  }

/* ----- issue summary ----- */

table.issuesummary
{
  text-align: left;
  }

table.issuesummary tr
{
  padding: 0em 0em 1em 0em;
  }

table.issuesummary td
{
  padding: 0em 1em 0em 0em;
  font-weight: normal;
  }

table.issuesummary th
{
  padding: 0em 1em 0em 0em;
  font-weight: normal;
  }

table.issuesummary h5
{
  padding: 0.5em 0em 0em 0em;
  }

/* ----- report files ----- */

table.reportfile
{
  text-align: left;
  }

table.reportfile tr
{
  padding: 0em 0em 1em 0em;
  }

table.reportfile td
{
  padding: 0em 1em 0em 0em;
  /* font-weight: bold; */
  }

table.reportfile th
{
  padding: 0em 1em 0em 2em;
  }

table.reportfile th
{
  font-weight: normal;
  }

table.reportfile h5
{
  padding: 0.5em 0em 0em 0em;
  }


/* ----- overview list ----- */

table.overviewlist
{
  text-align: left;
  }

table.overviewlist tr
{
  padding: 0em 0em 1em 0em;
  }

table.overviewlist th,
table.overviewlist td
{
  padding: 0em 1em 0em 0em;
  }

table.overviewlist th.overviewid,
table.overviewlist td.overviewid
{
  text-align: right;
  }


/* ----- tapper manual ----- */

.tappermanual h1,
.tappermanual h2,
.tappermanual h3,
.tappermanual h4,
.tappermanual h5,
.tappermanual h6
{
  font-weight: bold;
  padding: 0.1em 0.1em 0.1em 0.1em;
  border:  0.1em 0.1em 0.1em 0.1em;
  }

.tappermanual h2
{
  font-size: 2.2em;
  padding-bottom: 0.5em;
  }

.tappermanual h3
{
  margin-bottom: 0.1em;
  }

.tappermanual h4
{
  font-size: 1.8em;
  }

.tappermanual h5
{
  font-size: 1.0em;
  }

.tappermanual .node
{
  padding-bottom: 2em;
  }


/* -------------------------------------------------- */


